#!/bin/bash
#
# Source : http://mesh.dl.sourceforge.net/sourceforge/rssh/rssh-2.3.2.tar.gz
# Maintainer : Son|c <emmanuel.bailleul@cegetel.net>
#
#-( Date Of Build-Script Revision: Thursday 15 February 2007


#------------------( Set Package Variables )


soft='rssh'
softversion='2.3.2'
packageversion='48.1'


#------------------( Set Architecture Variables )

arch='i486'
cpu='i686'


#------------------( Set Architecture Variables )


buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"


#------------------( Prepare The Work Area And Source Package )


cd $buildir
rm -f {$dest,$dest.dep,$dest.md5,$dest.tgz,$package,$package.md5,$src} 1>/dev/null 2>&1
tar -xvzf $srcpkg
mkdir -p $dest


#------------------( Set Build Ownerships, Permissions and CFLAGS )


    chown -R root:root . 
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

export CFLAGS="-O2 -march=$arch -mtune=$cpu" 
export CXXFLAGS="$CFLAGS"


#------------------( A little Makefile patch )

sed -i 's/u+s\ \$(lib/u+s\ \$(DESTDIR)\$(lib/g' $src/Makefile.in

#------------------( Set Configuration Options )

cd $src
./configure --prefix=/usr \
  --sysconfdir=/etc 


#------------------( Make and Install Software )


make
make install DESTDIR=$dest
#make install
#------------------( Remove suid for security purpose )

chmod u-s $dest/usr/libexec/rssh_chroot_helper


#------------------ Strip Executables (Comment out these lines if debugging info is needed) )


cd $dest
chown -R root:root $dest/usr/bin
( cd $dest
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)


#------------------( Move Documentation To Correct Location )


cd $src
mkdir -p $dest/usr/doc/$soft-$softversion
cp -a \
  AUTHORS CHROOT COPYING ChangeLog INSTALL LICENSE NEWS README SECURITY TODO \
  $dest/usr/doc/$soft-$softversion


#------------------( Copy Build The Script )


mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/build-$soft.sh


#------------------( Create and Install The Slackdesc )


mkdir -p $dest/install
cat <<EOF > $dest/install/slack-desc 
    |-----handy-ruler------------------------------------------------------|
rssh: Restricted shell
rssh:
rssh: rssh is a restricted shell for use with OpenSSH, allowing only scp
rssh: and/or sftp. It now also includes support for rdist, rsync, and cvs.
rssh: For example, if you have a server which you only want to allow users
rssh: to copy files off of via scp, without providing shell access,
rssh: you can use rssh to do that
rssh:
rssh:
rssh:
rssh:
EOF


#------------------( Compress Man Pages )

( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)


#------------------( Relocate config file )

mv $dest/etc/rssh.conf $dest/etc/rssh.conf.new

#------------------( Create The doinst.sh File )
echo "config() {
   NEW=\"\$1.new\"
   OLD=\"\$1\"
   # If there's no config file by that name, mv it over :
   if [ ! -r \$OLD ]; then
	   mv \$NEW \$OLD
   elif [ \"\`cat \$OLD | md5sum\`\" = \"\`cat \$NEW | md5sum\`\" ]; \
   then # toss the redundant copy
	   rm \$NEW
   fi
   # Otherwise, we leave the .new copy for netpkg to consider ...
}
config etc/rssh.conf" > $dest/install/doinst.sh

chmod 755 $dest/install/doinst.sh

#------------------( Create The *.dep File )


cd $dest
requiredbuilder -z $dest > $buildir/$package.dep

#------------------( Compress The Package And Clean Up The Work Area )


cd $dest
makepkg -l y -c n $package.tgz
mv $package.tgz ../$package.tgz
rm -rf $src
rm -rf $dest


#------------------( Generate the MD5 Check Sum )


cd $buildir
rm -f $package.md5
md5sum $package.tgz > $package.md5

